package com.menagerie.ophelia.view

import androidx.compose.runtime.Composable
import androidx.navigation.NavController
import androidx.navigation.NavGraphBuilder
import androidx.navigation.NavHostController
import androidx.navigation.NavType
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import androidx.navigation.navArgument
import com.menagerie.ophelia.view.biographies.AddBiography
import com.menagerie.ophelia.view.biographies.BioDetailsScreen
import com.menagerie.ophelia.view.biographies.EditBiography
import com.menagerie.ophelia.view.newUser.AddNameScreen
import com.menagerie.ophelia.view.newUser.AddPronounsScreen
import com.menagerie.ophelia.view.newUser.AddTagsScreen
import com.menagerie.ophelia.view.newUser.ConfirmBio
import com.menagerie.ophelia.view.polycule.AddPolyculeScreen
import com.menagerie.ophelia.view.polycule.PolyculeHomeView

@Composable
fun PolyculeApp() {
    val navController = rememberNavController()
    PolyculeNavHost(
        navController = navController
    )
}

@Composable
fun PolyculeNavHost(
    navController: NavHostController
) {
    NavHost(
        navController = navController,
        startDestination = "confirmBio"
    ) {
        polyculeGraph(navController)
        welcomeGraph(navController)
        composable("home") {
            HomeScreen() {
                navController.navigate("newUserStart")
            }
        }
    }
}

fun NavGraphBuilder.welcomeGraph(navController: NavHostController) {
    composable("newUserStart") {
        NewUserStartScreen { navController.navigate("newUserName") }
    }
    composable("newUserName") {
        AddNameScreen { navController.navigate("newUserPronouns") }
    }
    composable("newUserPronouns") {
        AddPronounsScreen { navController.navigate("newUserTags") }
    }
    composable("newUserTags") {
        AddTagsScreen { navController.navigate("confirmBio") }
    }
    composable("confirmBio") {
        ConfirmBio {
            navController.popBackStack()
            navController.navigate("polyculeHome")
        }
    }
    composable("makePolycule") {
        AddPolyculeScreen()
    }
}

fun NavGraphBuilder.polyculeGraph(navController: NavController) {
    composable("polyculeHome") {
        PolyculeHomeView(
            onBioClick = {
                navController.navigate("bioDetail/${it.id}")
            },
            onAddClick = {
                navController.navigate("addBio") {}
            }
        )
    }
    composable(
        "bioDetail/{bioId}",
        arguments = listOf(navArgument("bioId") {
            type = NavType.LongType
        })
    ) {
        BioDetailsScreen(
            id = it.arguments?.getLong("bioId") ?: 0,
            onBackClick = { navController.navigateUp() },
            onEditClick = { id -> navController.navigate("editBio/${id}")}
        )
    }
    composable("addBio") {
        AddBiography()
    }
    composable(
        "editBio/{bioId}",
        arguments = listOf(navArgument("bioId") {
            type = NavType.LongType
        })
    ){
        EditBiography(bioId = it.arguments?.getLong("bioId") ?: 0) { navController.navigateUp() }
    }
}