package com.menagerie.ophelia.view.biographies

import android.annotation.SuppressLint
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.livedata.observeAsState
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import com.menagerie.ophelia.R
import com.menagerie.ophelia.database.polycule.entity.Bio
import com.menagerie.ophelia.database.polycule.entity.viewmodel.BioDetailViewModel
import com.menagerie.ophelia.view.components.fab.FABComponent
import com.menagerie.ophelia.view.components.utils.Dimens

data class BioDetailCallbacks(
    val onBackClick: () -> Unit,
    val onEditClick: (Long) -> Unit
)

@Composable
fun BioDetailsScreen(
    id: Long,
    onBackClick: () -> Unit,
    onEditClick: (Long) -> Unit,
) {
    val mBioDetailViewModel = BioDetailViewModel(id)

    val bio = mBioDetailViewModel.bio.observeAsState().value

    if (bio != null) {
        Surface {
            BioDetails(
                bio,
                BioDetailCallbacks(
                    onBackClick = onBackClick,
                    onEditClick = onEditClick,
                )
            )
        }
    }
}

@Composable
fun BioDetails(
    bio: Bio,
    callbacks: BioDetailCallbacks,
    modifier: Modifier = Modifier
) {
    Box(
        modifier
            .fillMaxSize()
    ) {
        BioDetailContents(
            bio = bio,
            onEdit = callbacks.onEditClick
        )
    }
}

@Composable
fun BioDetailContents(
    bio: Bio,
    onEdit: (Long) -> Unit,
) {
    Column {
        InfoDetails(
            bio = bio,
            onEdit = onEdit,
            modifier = Modifier
        )
    }
}

@SuppressLint("UnusedMaterial3ScaffoldPaddingParameter")
@Composable
fun InfoDetails(
    bio: Bio,
    onEdit: (Long) -> Unit,
    modifier: Modifier = Modifier
) {
    Scaffold(
        floatingActionButton = {
            FABComponent(
                text = "${stringResource(id = R.string.edit_bio)}",
                onClick = { onEdit(bio.id) }
            )
        }
    ) {
        Column(modifier = modifier.padding(Dimens.PaddingLarge)) {
            Text(
                text = bio.name,
                style = MaterialTheme.typography.displaySmall,
                modifier = Modifier
                    .padding(
                        start = Dimens.PaddingSmall,
                        end = Dimens.PaddingSmall,
                        bottom = Dimens.PaddingNormal
                    )
                    .align(Alignment.CenterHorizontally)
            )
            Box(
                Modifier
                    .align(Alignment.CenterHorizontally)
                    .padding(
                        start = Dimens.PaddingSmall,
                        end = Dimens.PaddingSmall,
                        bottom = Dimens.PaddingNormal
                    )
            ) {
                Text(text = "${bio.subjective} / ${bio.objective} / ${bio.possessive} / ${bio.reflexive}")
            }
        }
    }
}
