package com.menagerie.ophelia.view.newUser

import android.annotation.SuppressLint
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.text.KeyboardActions
import androidx.compose.material3.Button
import androidx.compose.material3.LinearProgressIndicator
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.livedata.observeAsState
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.focus.FocusDirection
import androidx.compose.ui.platform.LocalFocusManager
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import com.menagerie.ophelia.database.polycule.entity.Bio
import com.menagerie.ophelia.database.polycule.entity.viewmodel.BioDetailViewModel
import com.menagerie.ophelia.database.polycule.entity.viewmodel.BioListViewModel
import com.menagerie.ophelia.view.OpheliaFace
import com.menagerie.ophelia.view.OpheliaPronounsIntroduction
import com.menagerie.ophelia.view.components.InputField

@SuppressLint("UnusedMaterial3ScaffoldPaddingParameter")
@Composable
fun AddPronounsScreen(
    onGo : () -> Unit
) {
    val mBioDetailViewModel = BioDetailViewModel(1)
    val mBioListViewModel: BioListViewModel = viewModel(
        factory = BioListViewModel.BioListViewModelFactory()
    )

    val bio = mBioDetailViewModel.bio.observeAsState().value

    Scaffold {
        if (bio != null) {
            Column {
                OpheliaFace(
                    modifier = Modifier
                        .align(Alignment.CenterHorizontally)
                        .padding(top = 12.dp)
                )
                LinearProgressIndicator(
                    progress = .33f,
                    modifier = Modifier.fillMaxWidth()
                )
                OpheliaPronounsIntroduction(modifier = Modifier.weight(1f), name = bio.name)
                PronounBox(Modifier.weight(1f)) {
                    val updateBio = Bio(
                        id = bio.id,
                        name = bio.name,
                        subjective = it[0],
                        objective = it[1],
                        possessive = it[2],
                        reflexive = it[3],
                    )
                    mBioListViewModel.upsert(updateBio)
                    onGo()
                }
            }
        }
    }
}

@Composable
fun PronounBox(
    modifier: Modifier,
    onClick: (List<String>) -> Unit,
) {
    var subject by remember { mutableStateOf("") }
    var objec by remember { mutableStateOf("") }
    var possess by remember { mutableStateOf("") }
    var reflex by remember { mutableStateOf("") }


    Box(modifier = Modifier.fillMaxWidth())
    {
        Column {
            val focusManager = LocalFocusManager.current
            Row {
                InputField(
                    text = subject,
                    label = "subjective",
                    modifier = modifier,
                    onValChange = { subject = it },
                    keyboardActions = KeyboardActions(
                        onDone = { focusManager.moveFocus(FocusDirection.Next) }
                    ),
                )
                Text(
                    text = " / ",
                    style = MaterialTheme.typography.displayMedium
                )
                InputField(
                    text = objec,
                    label = "objective",
                    modifier = modifier,
                    onValChange = { objec = it },
                    keyboardActions = KeyboardActions(
                        onDone = { focusManager.moveFocus(FocusDirection.Next) }
                    ),
                )
            }
            Row {
                InputField(
                    text = possess,
                    label = "possessive",
                    modifier = modifier,
                    onValChange = { possess = it },
                    keyboardActions = KeyboardActions(
                        onDone = { focusManager.moveFocus(FocusDirection.Next) }
                    ),
                )
                Text(
                    text = " / ",
                    style = MaterialTheme.typography.displayMedium
                )
                InputField(
                    text = reflex,
                    label = "reflexive",
                    modifier = modifier,
                    onValChange = { reflex = it },
                    keyboardActions = KeyboardActions(
                        onDone = { focusManager.clearFocus() }
                    ),
                )
            }
            Spacer(
                modifier = Modifier.size(60.dp)
            )
            Button(
                onClick = {
                    onClick(listOf(subject, objec, possess, reflex))
                },
                modifier = Modifier
                    .align(
                        alignment = Alignment.End
                    )
                    .padding(8.dp)
            ) {
                Text(text = "Continue")
            }
        }
    }
}