package com.menagerie.ophelia.view.newUser

import android.annotation.SuppressLint
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.material3.Button
import androidx.compose.material3.LinearProgressIndicator
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.livedata.observeAsState
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import com.menagerie.ophelia.R
import com.menagerie.ophelia.database.polycule.entity.Bio
import com.menagerie.ophelia.database.polycule.entity.viewmodel.BioDetailViewModel
import com.menagerie.ophelia.database.polycule.entity.viewmodel.BioListViewModel
import com.menagerie.ophelia.view.OpheliaFace
import com.menagerie.ophelia.view.OpheliaTagsIntroduction
import com.menagerie.ophelia.view.biographies.TagCard

enum class Tags(val value: Int)
{
    TRANS(1),
    FURRY(2),
    ASEXUAL(4),
    BDSM(8),
    MONO(16),
    ALCOHOL(32),
    WEED(64),
    THERIAN(128),
    PLURAL(256),
}

@SuppressLint("UnusedMaterial3ScaffoldPaddingParameter")
@Composable
fun AddTagsScreen(
    onGo : () -> Unit
) {
        Scaffold {
        Column {
            OpheliaFace(
                modifier = Modifier
                    .align(Alignment.CenterHorizontally)
                    .padding(top = 12.dp)
            )
            LinearProgressIndicator(
                progress = .66f,
                modifier = Modifier.fillMaxWidth()
            )
            OpheliaTagsIntroduction(modifier = Modifier.weight(1f))
            MakeDefaultTagCards(modifier = Modifier.weight(2f))
            Button(
                onClick = onGo,
                modifier = Modifier
                    .weight(.25f)
                    .align(Alignment.End)) {
                Text(text = "Continue")
            }
        }
    }
}

@Composable
fun MakeDefaultTagCards(
    modifier: Modifier,
) {
    var flags by remember { mutableIntStateOf(0) }

    val mBioDetailViewModel = BioDetailViewModel(1)
    val mBioListViewModel: BioListViewModel = viewModel(
        factory = BioListViewModel.BioListViewModelFactory()
    )

    val bio = mBioDetailViewModel.bio.observeAsState().value

    if (bio != null) {
        val updateBio = Bio(
            id = bio.id,
            name = bio.name,
            subjective = bio.subjective,
            objective = bio.objective,
            possessive = bio.possessive,
            reflexive = bio.reflexive,
            tags = flags
        )
        mBioListViewModel.upsert(updateBio)

        Box(modifier = modifier) {
            LazyColumn {
                item {
                    TagCard(
                        name = "Transgender",
                        painter = painterResource(id = R.drawable.trans_tag),
                        details = "",
                        check = flags and Tags.TRANS.value == Tags.TRANS.value
                    ) {
                        flags = flags xor Tags.TRANS.value
                    }
                }
                item {
                    TagCard(
                        name = "Furry",
                        painter = painterResource(id = R.drawable.furry_tag),
                        details = "",
                        check = flags and Tags.FURRY.value == Tags.FURRY.value
                    ) {
                        flags = flags xor Tags.FURRY.value
                    }
                }
                item {
                    TagCard(
                        name = "Therian",
                        painter = painterResource(id = R.drawable.therian_tag),
                        details = "",
                        check = flags and Tags.THERIAN.value == Tags.THERIAN.value
                    ) {
                        flags = flags xor Tags.THERIAN.value
                    }
                }
                item {
                    TagCard(
                        name = "Monogamous",
                        painter = painterResource(id = R.drawable.mono_tag),
                        details = "",
                        check = flags and Tags.MONO.value == Tags.MONO.value
                    ) {
                        flags = flags xor Tags.MONO.value
                    }
                }
                item {
                    TagCard(
                        name = "BDSM",
                        painter = painterResource(id = R.drawable.bdsm_tag),
                        details = "",
                        check = flags and Tags.BDSM.value == Tags.BDSM.value
                    ) {
                        flags = flags xor Tags.BDSM.value
                    }
                }
                item {
                    TagCard(
                        name = "Plural",
                        painter = painterResource(id = R.drawable.plural_tag),
                        details = "",
                        check = flags and Tags.PLURAL.value == Tags.PLURAL.value
                    ) {
                        flags = flags xor Tags.PLURAL.value
                    }
                }
                item {
                    TagCard(
                        name = "Asexual",
                        painter = painterResource(id = R.drawable.asexual_tag),
                        details = "",
                        check = flags and Tags.ASEXUAL.value == Tags.ASEXUAL.value
                    ) {
                        flags = flags xor Tags.ASEXUAL.value
                    }
                }
                item {
                    TagCard(
                        name = "Alcohol",
                        painter = painterResource(id = R.drawable.liqour_tag),
                        details = "",
                        check = flags and Tags.ALCOHOL.value == Tags.ALCOHOL.value
                    ) {
                        flags = flags xor Tags.ALCOHOL.value
                    }
                }
                item {
                    TagCard(
                        name = "Weed",
                        painter = painterResource(id = R.drawable.weed_tag),
                        details = "",
                        check = flags and Tags.WEED.value == Tags.WEED.value
                    ) {
                        flags = flags xor Tags.WEED.value
                    }
                }
            }
        }
    }
}