package com.menagerie.ophelia.view.polycule

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.statusBarsPadding
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Add
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.FloatingActionButton
import androidx.compose.material3.Icon
import androidx.compose.material3.Scaffold
import androidx.compose.material3.TopAppBar
import androidx.compose.material3.TopAppBarDefaults
import androidx.compose.material3.TopAppBarScrollBehavior
import androidx.compose.runtime.Composable
import androidx.compose.runtime.livedata.observeAsState
import androidx.compose.ui.Modifier
import androidx.lifecycle.viewmodel.compose.viewModel
import com.menagerie.ophelia.database.polycule.entity.Bio
import com.menagerie.ophelia.database.polycule.entity.viewmodel.BioListViewModel
import com.menagerie.ophelia.view.biographies.BioCardList

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun PolyculeHomeView(
    modifier: Modifier = Modifier,
    onBioClick: (Bio) -> Unit = {},
    onAddClick: () -> Unit,
) {
    val scrollBehavior = TopAppBarDefaults.enterAlwaysScrollBehavior()
    Scaffold(
        modifier = modifier,
        topBar = {
            PolyculeTopAppBar(
                onFilterClick = { },
                scrollBehavior = scrollBehavior
            )
        }
    ) {
        PolyculeHomeScreen(
            onBioClick = onBioClick,
            onAddClick = onAddClick,
            modifier = modifier.padding(it)
        )
    }
}

@Composable
fun PolyculeHomeScreen(
    onBioClick: (Bio) -> Unit,
    onAddClick: () -> Unit = {},
    modifier: Modifier,
) {
    val mBioListViewModel: BioListViewModel = viewModel(
        factory = BioListViewModel.BioListViewModelFactory()
    )
    val items = mBioListViewModel.allBios.observeAsState(listOf()).value

    Column(
        modifier = modifier
    ) {
        BioCardList(bioList = items, onBioClick = onBioClick)
        FloatingActionButton(
            onClick = onAddClick
        ) {
            Icon(Icons.Filled.Add, "Add Bio")
        }
    }
}

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun PolyculeTopAppBar(
    onFilterClick: () -> Unit,
    modifier: Modifier = Modifier,
    scrollBehavior: TopAppBarScrollBehavior,
) {
    TopAppBar(
        title = {
            Row(
                Modifier.fillMaxWidth(),
                horizontalArrangement = Arrangement.Center,
            ) {
            }
        },
        modifier = modifier.statusBarsPadding(),
        actions = {},
        scrollBehavior = scrollBehavior
    )
}